# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'email_raw': 'str',
        'name': 'str',
        'name_raw': 'str',
        'phone_number': 'str',
        'phone_number_raw': 'str',
        'street': 'str',
        'street_raw': 'str',
        'postal_code': 'str',
        'postal_code_raw': 'str'
    }

    attribute_map = {
        'email': 'email',
        'email_raw': 'emailRaw',
        'name': 'name',
        'name_raw': 'nameRaw',
        'phone_number': 'phoneNumber',
        'phone_number_raw': 'phoneNumberRaw',
        'street': 'street',
        'street_raw': 'streetRaw',
        'postal_code': 'postalCode',
        'postal_code_raw': 'postalCodeRaw'
    }

    def __init__(self, email=None, email_raw=None, name=None, name_raw=None, phone_number=None, phone_number_raw=None, street=None, street_raw=None, postal_code=None, postal_code_raw=None):
        """
        TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults - a model defined in Swagger
        """

        self._email = None
        self._email_raw = None
        self._name = None
        self._name_raw = None
        self._phone_number = None
        self._phone_number_raw = None
        self._street = None
        self._street_raw = None
        self._postal_code = None
        self._postal_code_raw = None

        if email is not None:
          self.email = email
        if email_raw is not None:
          self.email_raw = email_raw
        if name is not None:
          self.name = name
        if name_raw is not None:
          self.name_raw = name_raw
        if phone_number is not None:
          self.phone_number = phone_number
        if phone_number_raw is not None:
          self.phone_number_raw = phone_number_raw
        if street is not None:
          self.street = street
        if street_raw is not None:
          self.street_raw = street_raw
        if postal_code is not None:
          self.postal_code = postal_code
        if postal_code_raw is not None:
          self.postal_code_raw = postal_code_raw

    @property
    def email(self):
        """
        Gets the email of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s email address.  For details, see `auth_ev_email` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The email of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s email address.  For details, see `auth_ev_email` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param email: The email of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if email is not None and len(email) > 1:
            raise ValueError("Invalid value for `email`, length must be less than or equal to `1`")

        self._email = email

    @property
    def email_raw(self):
        """
        Gets the email_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s email address.

        :return: The email_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._email_raw

    @email_raw.setter
    def email_raw(self, email_raw):
        """
        Sets the email_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s email address.

        :param email_raw: The email_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if email_raw is not None and len(email_raw) > 1:
            raise ValueError("Invalid value for `email_raw`, length must be less than or equal to `1`")

        self._email_raw = email_raw

    @property
    def name(self):
        """
        Gets the name of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s name. 

        :return: The name of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s name. 

        :param name: The name of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if name is not None and len(name) > 30:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `30`")

        self._name = name

    @property
    def name_raw(self):
        """
        Gets the name_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s name. 

        :return: The name_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._name_raw

    @name_raw.setter
    def name_raw(self, name_raw):
        """
        Sets the name_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s name. 

        :param name_raw: The name_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if name_raw is not None and len(name_raw) > 30:
            raise ValueError("Invalid value for `name_raw`, length must be less than or equal to `30`")

        self._name_raw = name_raw

    @property
    def phone_number(self):
        """
        Gets the phone_number of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s phone number.  For details, see `auth_ev_phone_number` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The phone_number of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s phone number.  For details, see `auth_ev_phone_number` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param phone_number: The phone_number of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 1:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `1`")

        self._phone_number = phone_number

    @property
    def phone_number_raw(self):
        """
        Gets the phone_number_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s phone number.

        :return: The phone_number_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._phone_number_raw

    @phone_number_raw.setter
    def phone_number_raw(self, phone_number_raw):
        """
        Sets the phone_number_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s phone number.

        :param phone_number_raw: The phone_number_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if phone_number_raw is not None and len(phone_number_raw) > 1:
            raise ValueError("Invalid value for `phone_number_raw`, length must be less than or equal to `1`")

        self._phone_number_raw = phone_number_raw

    @property
    def street(self):
        """
        Gets the street of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s street address.  For details, see `auth_ev_street` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The street of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """
        Sets the street of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s street address.  For details, see `auth_ev_street` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param street: The street of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if street is not None and len(street) > 1:
            raise ValueError("Invalid value for `street`, length must be less than or equal to `1`")

        self._street = street

    @property
    def street_raw(self):
        """
        Gets the street_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s street address.

        :return: The street_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._street_raw

    @street_raw.setter
    def street_raw(self, street_raw):
        """
        Sets the street_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s street address.

        :param street_raw: The street_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if street_raw is not None and len(street_raw) > 1:
            raise ValueError("Invalid value for `street_raw`, length must be less than or equal to `1`")

        self._street_raw = street_raw

    @property
    def postal_code(self):
        """
        Gets the postal_code of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s postal code.  For details, see `auth_ev_postal_code` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The postal_code of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Mapped Electronic Verification response code for the customer’s postal code.  For details, see `auth_ev_postal_code` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param postal_code: The postal_code of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 1:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `1`")

        self._postal_code = postal_code

    @property
    def postal_code_raw(self):
        """
        Gets the postal_code_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s postal code.

        :return: The postal_code_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :rtype: str
        """
        return self._postal_code_raw

    @postal_code_raw.setter
    def postal_code_raw(self, postal_code_raw):
        """
        Sets the postal_code_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        Raw Electronic Verification response code from the processor for the customer’s postal code.

        :param postal_code_raw: The postal_code_raw of this TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults.
        :type: str
        """
        if postal_code_raw is not None and len(postal_code_raw) > 1:
            raise ValueError("Invalid value for `postal_code_raw`, length must be less than or equal to `1`")

        self._postal_code_raw = postal_code_raw

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseProcessorInformationElectronicVerificationResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UmsV1UsersGet200ResponseAccountInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_name': 'str',
        'role_id': 'str',
        'permissions': 'list[str]',
        'status': 'str',
        'created_time': 'datetime',
        'last_access_time': 'datetime',
        'language_preference': 'str',
        'timezone': 'str'
    }

    attribute_map = {
        'user_name': 'userName',
        'role_id': 'roleId',
        'permissions': 'permissions',
        'status': 'status',
        'created_time': 'createdTime',
        'last_access_time': 'lastAccessTime',
        'language_preference': 'languagePreference',
        'timezone': 'timezone'
    }

    def __init__(self, user_name=None, role_id=None, permissions=None, status=None, created_time=None, last_access_time=None, language_preference=None, timezone=None):
        """
        UmsV1UsersGet200ResponseAccountInformation - a model defined in Swagger
        """

        self._user_name = None
        self._role_id = None
        self._permissions = None
        self._status = None
        self._created_time = None
        self._last_access_time = None
        self._language_preference = None
        self._timezone = None

        if user_name is not None:
          self.user_name = user_name
        if role_id is not None:
          self.role_id = role_id
        if permissions is not None:
          self.permissions = permissions
        if status is not None:
          self.status = status
        if created_time is not None:
          self.created_time = created_time
        if last_access_time is not None:
          self.last_access_time = last_access_time
        if language_preference is not None:
          self.language_preference = language_preference
        if timezone is not None:
          self.timezone = timezone

    @property
    def user_name(self):
        """
        Gets the user_name of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The user_name of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this UmsV1UsersGet200ResponseAccountInformation.

        :param user_name: The user_name of this UmsV1UsersGet200ResponseAccountInformation.
        :type: str
        """

        self._user_name = user_name

    @property
    def role_id(self):
        """
        Gets the role_id of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The role_id of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """
        Sets the role_id of this UmsV1UsersGet200ResponseAccountInformation.

        :param role_id: The role_id of this UmsV1UsersGet200ResponseAccountInformation.
        :type: str
        """

        self._role_id = role_id

    @property
    def permissions(self):
        """
        Gets the permissions of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The permissions of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """
        Sets the permissions of this UmsV1UsersGet200ResponseAccountInformation.

        :param permissions: The permissions of this UmsV1UsersGet200ResponseAccountInformation.
        :type: list[str]
        """

        self._permissions = permissions

    @property
    def status(self):
        """
        Gets the status of this UmsV1UsersGet200ResponseAccountInformation.
        Valid values: - active - inactive - locked - disabled - forgotpassword - deleted 

        :return: The status of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UmsV1UsersGet200ResponseAccountInformation.
        Valid values: - active - inactive - locked - disabled - forgotpassword - deleted 

        :param status: The status of this UmsV1UsersGet200ResponseAccountInformation.
        :type: str
        """

        self._status = status

    @property
    def created_time(self):
        """
        Gets the created_time of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The created_time of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """
        Sets the created_time of this UmsV1UsersGet200ResponseAccountInformation.

        :param created_time: The created_time of this UmsV1UsersGet200ResponseAccountInformation.
        :type: datetime
        """

        self._created_time = created_time

    @property
    def last_access_time(self):
        """
        Gets the last_access_time of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The last_access_time of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: datetime
        """
        return self._last_access_time

    @last_access_time.setter
    def last_access_time(self, last_access_time):
        """
        Sets the last_access_time of this UmsV1UsersGet200ResponseAccountInformation.

        :param last_access_time: The last_access_time of this UmsV1UsersGet200ResponseAccountInformation.
        :type: datetime
        """

        self._last_access_time = last_access_time

    @property
    def language_preference(self):
        """
        Gets the language_preference of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The language_preference of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: str
        """
        return self._language_preference

    @language_preference.setter
    def language_preference(self, language_preference):
        """
        Sets the language_preference of this UmsV1UsersGet200ResponseAccountInformation.

        :param language_preference: The language_preference of this UmsV1UsersGet200ResponseAccountInformation.
        :type: str
        """

        self._language_preference = language_preference

    @property
    def timezone(self):
        """
        Gets the timezone of this UmsV1UsersGet200ResponseAccountInformation.

        :return: The timezone of this UmsV1UsersGet200ResponseAccountInformation.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this UmsV1UsersGet200ResponseAccountInformation.

        :param timezone: The timezone of this UmsV1UsersGet200ResponseAccountInformation.
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UmsV1UsersGet200ResponseAccountInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoicingV2InvoicesGet200ResponseInvoiceHistory(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event': 'str',
        'date': 'datetime',
        'transaction_details': 'InvoicingV2InvoicesGet200ResponseTransactionDetails'
    }

    attribute_map = {
        'event': 'event',
        'date': 'date',
        'transaction_details': 'transactionDetails'
    }

    def __init__(self, event=None, date=None, transaction_details=None):
        """
        InvoicingV2InvoicesGet200ResponseInvoiceHistory - a model defined in Swagger
        """

        self._event = None
        self._date = None
        self._transaction_details = None

        if event is not None:
          self.event = event
        if date is not None:
          self.date = date
        if transaction_details is not None:
          self.transaction_details = transaction_details

    @property
    def event(self):
        """
        Gets the event of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        The event triggered for the invoice.  Possible values:  - `CREATE`  - `UPDATE`  - `SEND`  - `RESEND`  - `REMINDER`  - `PAYMENT`  - `CANCEL` 

        :return: The event of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """
        Sets the event of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        The event triggered for the invoice.  Possible values:  - `CREATE`  - `UPDATE`  - `SEND`  - `RESEND`  - `REMINDER`  - `PAYMENT`  - `CANCEL` 

        :param event: The event of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :type: str
        """

        self._event = event

    @property
    def date(self):
        """
        Gets the date of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        The date and time when the invoice event was triggered in ISO 8601 format. Format: YYYY-MM-DDThh:mm:ssZ 

        :return: The date of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        The date and time when the invoice event was triggered in ISO 8601 format. Format: YYYY-MM-DDThh:mm:ssZ 

        :param date: The date of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :type: datetime
        """

        self._date = date

    @property
    def transaction_details(self):
        """
        Gets the transaction_details of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.

        :return: The transaction_details of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :rtype: InvoicingV2InvoicesGet200ResponseTransactionDetails
        """
        return self._transaction_details

    @transaction_details.setter
    def transaction_details(self, transaction_details):
        """
        Sets the transaction_details of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.

        :param transaction_details: The transaction_details of this InvoicingV2InvoicesGet200ResponseInvoiceHistory.
        :type: InvoicingV2InvoicesGet200ResponseTransactionDetails
        """

        self._transaction_details = transaction_details

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoicingV2InvoicesGet200ResponseInvoiceHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class VasV2PaymentsPost201ResponseOrderInformationLineItems(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tax_details': 'list[VasV2PaymentsPost201ResponseOrderInformationTaxDetails]',
        'jurisdiction': 'list[VasV2PaymentsPost201ResponseOrderInformationJurisdiction]',
        'exempt_amount': 'str',
        'taxable_amount': 'str',
        'tax_amount': 'str'
    }

    attribute_map = {
        'tax_details': 'taxDetails',
        'jurisdiction': 'jurisdiction',
        'exempt_amount': 'exemptAmount',
        'taxable_amount': 'taxableAmount',
        'tax_amount': 'taxAmount'
    }

    def __init__(self, tax_details=None, jurisdiction=None, exempt_amount=None, taxable_amount=None, tax_amount=None):
        """
        VasV2PaymentsPost201ResponseOrderInformationLineItems - a model defined in Swagger
        """

        self._tax_details = None
        self._jurisdiction = None
        self._exempt_amount = None
        self._taxable_amount = None
        self._tax_amount = None

        if tax_details is not None:
          self.tax_details = tax_details
        if jurisdiction is not None:
          self.jurisdiction = jurisdiction
        if exempt_amount is not None:
          self.exempt_amount = exempt_amount
        if taxable_amount is not None:
          self.taxable_amount = taxable_amount
        if tax_amount is not None:
          self.tax_amount = tax_amount

    @property
    def tax_details(self):
        """
        Gets the tax_details of this VasV2PaymentsPost201ResponseOrderInformationLineItems.

        :return: The tax_details of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :rtype: list[VasV2PaymentsPost201ResponseOrderInformationTaxDetails]
        """
        return self._tax_details

    @tax_details.setter
    def tax_details(self, tax_details):
        """
        Sets the tax_details of this VasV2PaymentsPost201ResponseOrderInformationLineItems.

        :param tax_details: The tax_details of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :type: list[VasV2PaymentsPost201ResponseOrderInformationTaxDetails]
        """

        self._tax_details = tax_details

    @property
    def jurisdiction(self):
        """
        Gets the jurisdiction of this VasV2PaymentsPost201ResponseOrderInformationLineItems.

        :return: The jurisdiction of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :rtype: list[VasV2PaymentsPost201ResponseOrderInformationJurisdiction]
        """
        return self._jurisdiction

    @jurisdiction.setter
    def jurisdiction(self, jurisdiction):
        """
        Sets the jurisdiction of this VasV2PaymentsPost201ResponseOrderInformationLineItems.

        :param jurisdiction: The jurisdiction of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :type: list[VasV2PaymentsPost201ResponseOrderInformationJurisdiction]
        """

        self._jurisdiction = jurisdiction

    @property
    def exempt_amount(self):
        """
        Gets the exempt_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Exempt amount for the lineItem. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The exempt_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._exempt_amount

    @exempt_amount.setter
    def exempt_amount(self, exempt_amount):
        """
        Sets the exempt_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Exempt amount for the lineItem. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param exempt_amount: The exempt_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :type: str
        """
        if exempt_amount is not None and len(exempt_amount) > 15:
            raise ValueError("Invalid value for `exempt_amount`, length must be less than or equal to `15`")

        self._exempt_amount = exempt_amount

    @property
    def taxable_amount(self):
        """
        Gets the taxable_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Portion of the item amount that is taxable. 

        :return: The taxable_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._taxable_amount

    @taxable_amount.setter
    def taxable_amount(self, taxable_amount):
        """
        Sets the taxable_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Portion of the item amount that is taxable. 

        :param taxable_amount: The taxable_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :type: str
        """
        if taxable_amount is not None and len(taxable_amount) > 15:
            raise ValueError("Invalid value for `taxable_amount`, length must be less than or equal to `15`")

        self._taxable_amount = taxable_amount

    @property
    def tax_amount(self):
        """
        Gets the tax_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Total tax for the item. This value is the sum of all taxes applied to the item. 

        :return: The tax_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :rtype: str
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """
        Sets the tax_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        Total tax for the item. This value is the sum of all taxes applied to the item. 

        :param tax_amount: The tax_amount of this VasV2PaymentsPost201ResponseOrderInformationLineItems.
        :type: str
        """
        if tax_amount is not None and len(tax_amount) > 15:
            raise ValueError("Invalid value for `tax_amount`, length must be less than or equal to `15`")

        self._tax_amount = tax_amount

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VasV2PaymentsPost201ResponseOrderInformationLineItems):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ShippingAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'Tmsv2customersEmbeddedDefaultShippingAddressLinks',
        'id': 'str',
        'ship_to': 'Tmsv2customersEmbeddedDefaultShippingAddressShipTo',
        'metadata': 'Tmsv2customersEmbeddedDefaultShippingAddressMetadata'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'ship_to': 'shipTo',
        'metadata': 'metadata'
    }

    def __init__(self, links=None, id=None, ship_to=None, metadata=None):
        """
        ShippingAddress - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._ship_to = None
        self._metadata = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if ship_to is not None:
          self.ship_to = ship_to
        if metadata is not None:
          self.metadata = metadata

    @property
    def links(self):
        """
        Gets the links of this ShippingAddress.

        :return: The links of this ShippingAddress.
        :rtype: Tmsv2customersEmbeddedDefaultShippingAddressLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this ShippingAddress.

        :param links: The links of this ShippingAddress.
        :type: Tmsv2customersEmbeddedDefaultShippingAddressLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this ShippingAddress.
        The id of the Shipping Address Token.

        :return: The id of this ShippingAddress.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ShippingAddress.
        The id of the Shipping Address Token.

        :param id: The id of this ShippingAddress.
        :type: str
        """
        if id is not None and len(id) > 32:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `32`")
        if id is not None and len(id) < 1:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `1`")

        self._id = id

    @property
    def ship_to(self):
        """
        Gets the ship_to of this ShippingAddress.

        :return: The ship_to of this ShippingAddress.
        :rtype: Tmsv2customersEmbeddedDefaultShippingAddressShipTo
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """
        Sets the ship_to of this ShippingAddress.

        :param ship_to: The ship_to of this ShippingAddress.
        :type: Tmsv2customersEmbeddedDefaultShippingAddressShipTo
        """

        self._ship_to = ship_to

    @property
    def metadata(self):
        """
        Gets the metadata of this ShippingAddress.

        :return: The metadata of this ShippingAddress.
        :rtype: Tmsv2customersEmbeddedDefaultShippingAddressMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ShippingAddress.

        :param metadata: The metadata of this ShippingAddress.
        :type: Tmsv2customersEmbeddedDefaultShippingAddressMetadata
        """

        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ShippingAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3ReportDefinitionsNameGet200Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'report_definition_id': 'int',
        'report_defintion_name': 'str',
        'attributes': 'list[ReportingV3ReportDefinitionsNameGet200ResponseAttributes]',
        'supported_formats': 'list[str]',
        'description': 'str',
        'default_settings': 'ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings',
        'subscription_type': 'str'
    }

    attribute_map = {
        'type': 'type',
        'report_definition_id': 'reportDefinitionId',
        'report_defintion_name': 'reportDefintionName',
        'attributes': 'attributes',
        'supported_formats': 'supportedFormats',
        'description': 'description',
        'default_settings': 'defaultSettings',
        'subscription_type': 'subscriptionType'
    }

    def __init__(self, type=None, report_definition_id=None, report_defintion_name=None, attributes=None, supported_formats=None, description=None, default_settings=None, subscription_type=None):
        """
        ReportingV3ReportDefinitionsNameGet200Response - a model defined in Swagger
        """

        self._type = None
        self._report_definition_id = None
        self._report_defintion_name = None
        self._attributes = None
        self._supported_formats = None
        self._description = None
        self._default_settings = None
        self._subscription_type = None

        if type is not None:
          self.type = type
        if report_definition_id is not None:
          self.report_definition_id = report_definition_id
        if report_defintion_name is not None:
          self.report_defintion_name = report_defintion_name
        if attributes is not None:
          self.attributes = attributes
        if supported_formats is not None:
          self.supported_formats = supported_formats
        if description is not None:
          self.description = description
        if default_settings is not None:
          self.default_settings = default_settings
        if subscription_type is not None:
          self.subscription_type = subscription_type

    @property
    def type(self):
        """
        Gets the type of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The type of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ReportingV3ReportDefinitionsNameGet200Response.

        :param type: The type of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: str
        """

        self._type = type

    @property
    def report_definition_id(self):
        """
        Gets the report_definition_id of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The report_definition_id of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: int
        """
        return self._report_definition_id

    @report_definition_id.setter
    def report_definition_id(self, report_definition_id):
        """
        Sets the report_definition_id of this ReportingV3ReportDefinitionsNameGet200Response.

        :param report_definition_id: The report_definition_id of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: int
        """

        self._report_definition_id = report_definition_id

    @property
    def report_defintion_name(self):
        """
        Gets the report_defintion_name of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The report_defintion_name of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: str
        """
        return self._report_defintion_name

    @report_defintion_name.setter
    def report_defintion_name(self, report_defintion_name):
        """
        Sets the report_defintion_name of this ReportingV3ReportDefinitionsNameGet200Response.

        :param report_defintion_name: The report_defintion_name of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: str
        """

        self._report_defintion_name = report_defintion_name

    @property
    def attributes(self):
        """
        Gets the attributes of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The attributes of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: list[ReportingV3ReportDefinitionsNameGet200ResponseAttributes]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ReportingV3ReportDefinitionsNameGet200Response.

        :param attributes: The attributes of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: list[ReportingV3ReportDefinitionsNameGet200ResponseAttributes]
        """

        self._attributes = attributes

    @property
    def supported_formats(self):
        """
        Gets the supported_formats of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The supported_formats of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: list[str]
        """
        return self._supported_formats

    @supported_formats.setter
    def supported_formats(self, supported_formats):
        """
        Sets the supported_formats of this ReportingV3ReportDefinitionsNameGet200Response.

        :param supported_formats: The supported_formats of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: list[str]
        """

        self._supported_formats = supported_formats

    @property
    def description(self):
        """
        Gets the description of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The description of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportingV3ReportDefinitionsNameGet200Response.

        :param description: The description of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: str
        """

        self._description = description

    @property
    def default_settings(self):
        """
        Gets the default_settings of this ReportingV3ReportDefinitionsNameGet200Response.

        :return: The default_settings of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings
        """
        return self._default_settings

    @default_settings.setter
    def default_settings(self, default_settings):
        """
        Sets the default_settings of this ReportingV3ReportDefinitionsNameGet200Response.

        :param default_settings: The default_settings of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings
        """

        self._default_settings = default_settings

    @property
    def subscription_type(self):
        """
        Gets the subscription_type of this ReportingV3ReportDefinitionsNameGet200Response.
        'The subscription type for which report definition is required. By default the type will be CUSTOM.' Valid Values: - 'CLASSIC' - 'CUSTOM' - 'STANDARD' 

        :return: The subscription_type of this ReportingV3ReportDefinitionsNameGet200Response.
        :rtype: str
        """
        return self._subscription_type

    @subscription_type.setter
    def subscription_type(self, subscription_type):
        """
        Sets the subscription_type of this ReportingV3ReportDefinitionsNameGet200Response.
        'The subscription type for which report definition is required. By default the type will be CUSTOM.' Valid Values: - 'CLASSIC' - 'CUSTOM' - 'STANDARD' 

        :param subscription_type: The subscription_type of this ReportingV3ReportDefinitionsNameGet200Response.
        :type: str
        """

        self._subscription_type = subscription_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3ReportDefinitionsNameGet200Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidreversalsClientReferenceInformationPartner(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'developer_id': 'str',
        'solution_id': 'str',
        'third_party_certification_number': 'str'
    }

    attribute_map = {
        'developer_id': 'developerId',
        'solution_id': 'solutionId',
        'third_party_certification_number': 'thirdPartyCertificationNumber'
    }

    def __init__(self, developer_id=None, solution_id=None, third_party_certification_number=None):
        """
        Ptsv2paymentsidreversalsClientReferenceInformationPartner - a model defined in Swagger
        """

        self._developer_id = None
        self._solution_id = None
        self._third_party_certification_number = None

        if developer_id is not None:
          self.developer_id = developer_id
        if solution_id is not None:
          self.solution_id = solution_id
        if third_party_certification_number is not None:
          self.third_party_certification_number = third_party_certification_number

    @property
    def developer_id(self):
        """
        Gets the developer_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Identifier for the developer that helped integrate a partner solution to CyberSource.  Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer.  **Note** When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect. 

        :return: The developer_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :rtype: str
        """
        return self._developer_id

    @developer_id.setter
    def developer_id(self, developer_id):
        """
        Sets the developer_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Identifier for the developer that helped integrate a partner solution to CyberSource.  Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer.  **Note** When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect. 

        :param developer_id: The developer_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :type: str
        """
        if developer_id is not None and len(developer_id) > 8:
            raise ValueError("Invalid value for `developer_id`, length must be less than or equal to `8`")

        self._developer_id = developer_id

    @property
    def solution_id(self):
        """
        Gets the solution_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Identifier for the partner that is integrated to CyberSource.  Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner.  **Note** When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect. 

        :return: The solution_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :rtype: str
        """
        return self._solution_id

    @solution_id.setter
    def solution_id(self, solution_id):
        """
        Sets the solution_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Identifier for the partner that is integrated to CyberSource.  Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner.  **Note** When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect. 

        :param solution_id: The solution_id of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :type: str
        """
        if solution_id is not None and len(solution_id) > 8:
            raise ValueError("Invalid value for `solution_id`, length must be less than or equal to `8`")

        self._solution_id = solution_id

    @property
    def third_party_certification_number(self):
        """
        Gets the third_party_certification_number of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Value that identifies the application vendor and application version for a third party gateway. CyberSource provides you with this value during testing and validation. This field is supported only on CyberSource through VisaNet.  #### Used by **Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void** Optional field.  #### PIN debit Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request. 

        :return: The third_party_certification_number of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :rtype: str
        """
        return self._third_party_certification_number

    @third_party_certification_number.setter
    def third_party_certification_number(self, third_party_certification_number):
        """
        Sets the third_party_certification_number of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        Value that identifies the application vendor and application version for a third party gateway. CyberSource provides you with this value during testing and validation. This field is supported only on CyberSource through VisaNet.  #### Used by **Authorization, Authorization Reversal, Capture, Credit, Incremental Authorization, and Void** Optional field.  #### PIN debit Required field for PIN debit credit, PIN debit purchase, or PIN debit reversal request. 

        :param third_party_certification_number: The third_party_certification_number of this Ptsv2paymentsidreversalsClientReferenceInformationPartner.
        :type: str
        """
        if third_party_certification_number is not None and len(third_party_certification_number) > 12:
            raise ValueError("Invalid value for `third_party_certification_number`, length must be less than or equal to `12`")

        self._third_party_certification_number = third_party_certification_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidreversalsClientReferenceInformationPartner):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1decisionsTravelInformationPassengers(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName'
    }

    def __init__(self, first_name=None, last_name=None):
        """
        Riskv1decisionsTravelInformationPassengers - a model defined in Swagger
        """

        self._first_name = None
        self._last_name = None

        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name

    @property
    def first_name(self):
        """
        Gets the first_name of this Riskv1decisionsTravelInformationPassengers.
        First name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests. 

        :return: The first_name of this Riskv1decisionsTravelInformationPassengers.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Riskv1decisionsTravelInformationPassengers.
        First name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests. 

        :param first_name: The first_name of this Riskv1decisionsTravelInformationPassengers.
        :type: str
        """
        if first_name is not None and len(first_name) > 60:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `60`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this Riskv1decisionsTravelInformationPassengers.
        Last name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests. 

        :return: The last_name of this Riskv1decisionsTravelInformationPassengers.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Riskv1decisionsTravelInformationPassengers.
        Last name of the passenger to whom the ticket was issued. If there are multiple passengers, include all listed on the ticket. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Required for American Express SafeKey (U.S.) for travel-related requests. 

        :param last_name: The last_name of this Riskv1decisionsTravelInformationPassengers.
        :type: str
        """
        if last_name is not None and len(last_name) > 60:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `60`")

        self._last_name = last_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1decisionsTravelInformationPassengers):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'suffix': 'str',
        'prefix': 'str',
        'type': 'str'
    }

    attribute_map = {
        'suffix': 'suffix',
        'prefix': 'prefix',
        'type': 'type'
    }

    def __init__(self, suffix=None, prefix=None, type=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard - a model defined in Swagger
        """

        self._suffix = None
        self._prefix = None
        self._type = None

        if suffix is not None:
          self.suffix = suffix
        if prefix is not None:
          self.prefix = prefix
        if type is not None:
          self.type = type

    @property
    def suffix(self):
        """
        Gets the suffix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Last four digits of the cardholder’s account number. This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details.  You must contact customer support to have your account enabled to receive these fields in the credit reply message.  #### PIN debit This field is returned only for tokenized transactions. You can use this value on the receipt that you give to the cardholder.  Returned by PIN debit credit and PIN debit purchase.  This field is supported only by the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :return: The suffix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """
        Sets the suffix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Last four digits of the cardholder’s account number. This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details.  You must contact customer support to have your account enabled to receive these fields in the credit reply message.  #### PIN debit This field is returned only for tokenized transactions. You can use this value on the receipt that you give to the cardholder.  Returned by PIN debit credit and PIN debit purchase.  This field is supported only by the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :param suffix: The suffix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :type: str
        """

        self._suffix = suffix

    @property
    def prefix(self):
        """
        Gets the prefix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Bank Identification Number (BIN). This is the initial four to six numbers on a credit card account number. 

        :return: The prefix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Bank Identification Number (BIN). This is the initial four to six numbers on a credit card account number. 

        :param prefix: The prefix of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :type: str
        """
        if prefix is not None and len(prefix) > 6:
            raise ValueError("Invalid value for `prefix`, length must be less than or equal to `6`")

        self._prefix = prefix

    @property
    def type(self):
        """
        Gets the type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Three-digit value that indicates the card type.  **IMPORTANT** It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type.  Possible values: - `001`: Visa. For card-present transactions on all processors except SIX, the Visa Electron card type is processed the same way that the Visa debit card is processed. Use card type value `001` for Visa Electron. - `002`: Mastercard, Eurocard[^1], which is a European regional brand of Mastercard. - `003`: American Express - `004`: Discover - `005`: Diners Club - `006`: Carte Blanche[^1] - `007`: JCB[^1] - `014`: Enroute[^1] - `021`: JAL[^1] - `024`: Maestro (UK Domestic)[^1] - `031`: Delta[^1]: Use this value only for Ingenico ePayments. For other processors, use `001` for all Visa card types. - `033`: Visa Electron[^1]. Use this value only for Ingenico ePayments and SIX. For other processors, use `001` for all Visa card types. - `034`: Dankort[^1] - `036`: Cartes Bancaires[^1] - `037`: Carta Si[^1] - `039`: Encoded account number[^1] - `040`: UATP[^1] - `042`: Maestro (International)[^1] - `050`: Hipercard[^2,3] - `051`: Aura - `054`: Elo[^3] - `062`: China UnionPay  [^1]: For this card type, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in a request for an authorization or a stand-alone credit.  #### Used by **Authorization** Required for Carte Blanche and JCB. Optional for all other card types.  #### Card Present reply This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message.  Returned by the Credit service.  This reply field is only supported by the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX  #### GPX This field only supports transactions from the following card types: - Visa - Mastercard - AMEX - Discover - Diners - JCB - Union Pay International 

        :return: The type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        Three-digit value that indicates the card type.  **IMPORTANT** It is strongly recommended that you include the card type field in request messages even if it is optional for your processor and card type. Omitting the card type can cause the transaction to be processed with the wrong card type.  Possible values: - `001`: Visa. For card-present transactions on all processors except SIX, the Visa Electron card type is processed the same way that the Visa debit card is processed. Use card type value `001` for Visa Electron. - `002`: Mastercard, Eurocard[^1], which is a European regional brand of Mastercard. - `003`: American Express - `004`: Discover - `005`: Diners Club - `006`: Carte Blanche[^1] - `007`: JCB[^1] - `014`: Enroute[^1] - `021`: JAL[^1] - `024`: Maestro (UK Domestic)[^1] - `031`: Delta[^1]: Use this value only for Ingenico ePayments. For other processors, use `001` for all Visa card types. - `033`: Visa Electron[^1]. Use this value only for Ingenico ePayments and SIX. For other processors, use `001` for all Visa card types. - `034`: Dankort[^1] - `036`: Cartes Bancaires[^1] - `037`: Carta Si[^1] - `039`: Encoded account number[^1] - `040`: UATP[^1] - `042`: Maestro (International)[^1] - `050`: Hipercard[^2,3] - `051`: Aura - `054`: Elo[^3] - `062`: China UnionPay  [^1]: For this card type, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in your request for an authorization or a stand-alone credit. [^2]: For this card type on Cielo 3.0, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in a request for an authorization or a stand-alone credit. This card type is not supported on Cielo 1.5. [^3]: For this card type on Getnet and Rede, you must include the `paymentInformation.card.type` or `paymentInformation.tokenizedCard.type` field in a request for an authorization or a stand-alone credit.  #### Used by **Authorization** Required for Carte Blanche and JCB. Optional for all other card types.  #### Card Present reply This field is included in the reply message when the client software that is installed on the POS terminal uses the token management service (TMS) to retrieve tokenized payment details. You must contact customer support to have your account enabled to receive these fields in the credit reply message.  Returned by the Credit service.  This reply field is only supported by the following processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX  #### GPX This field only supports transactions from the following card types: - Visa - Mastercard - AMEX - Discover - Diners - JCB - Union Pay International 

        :param type: The type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedPaymentInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_type': 'TssV2TransactionsPost201ResponseEmbeddedPaymentInformationPaymentType',
        'customer': 'Riskv1authenticationsetupsPaymentInformationCustomer',
        'card': 'TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard'
    }

    attribute_map = {
        'payment_type': 'paymentType',
        'customer': 'customer',
        'card': 'card'
    }

    def __init__(self, payment_type=None, customer=None, card=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedPaymentInformation - a model defined in Swagger
        """

        self._payment_type = None
        self._customer = None
        self._card = None

        if payment_type is not None:
          self.payment_type = payment_type
        if customer is not None:
          self.customer = customer
        if card is not None:
          self.card = card

    @property
    def payment_type(self):
        """
        Gets the payment_type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :return: The payment_type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedPaymentInformationPaymentType
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """
        Sets the payment_type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :param payment_type: The payment_type of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :type: TssV2TransactionsPost201ResponseEmbeddedPaymentInformationPaymentType
        """

        self._payment_type = payment_type

    @property
    def customer(self):
        """
        Gets the customer of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :return: The customer of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :rtype: Riskv1authenticationsetupsPaymentInformationCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """
        Sets the customer of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :param customer: The customer of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :type: Riskv1authenticationsetupsPaymentInformationCustomer
        """

        self._customer = customer

    @property
    def card(self):
        """
        Gets the card of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :return: The card of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :rtype: TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """
        Sets the card of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.

        :param card: The card of this TssV2TransactionsPost201ResponseEmbeddedPaymentInformation.
        :type: TssV2TransactionsPost201ResponseEmbeddedPaymentInformationCard
        """

        self._card = card

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedPaymentInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationsOrderInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_details': 'Riskv1authenticationsOrderInformationAmountDetails',
        'pre_order': 'str',
        'pre_order_date': 'str',
        'reordered': 'bool',
        'ship_to': 'Riskv1decisionsOrderInformationShipTo',
        'line_items': 'list[Riskv1authenticationsOrderInformationLineItems]',
        'bill_to': 'Riskv1authenticationsOrderInformationBillTo',
        'total_offers_count': 'str'
    }

    attribute_map = {
        'amount_details': 'amountDetails',
        'pre_order': 'preOrder',
        'pre_order_date': 'preOrderDate',
        'reordered': 'reordered',
        'ship_to': 'shipTo',
        'line_items': 'lineItems',
        'bill_to': 'billTo',
        'total_offers_count': 'totalOffersCount'
    }

    def __init__(self, amount_details=None, pre_order=None, pre_order_date=None, reordered=None, ship_to=None, line_items=None, bill_to=None, total_offers_count=None):
        """
        Riskv1authenticationsOrderInformation - a model defined in Swagger
        """

        self._amount_details = None
        self._pre_order = None
        self._pre_order_date = None
        self._reordered = None
        self._ship_to = None
        self._line_items = None
        self._bill_to = None
        self._total_offers_count = None

        if amount_details is not None:
          self.amount_details = amount_details
        if pre_order is not None:
          self.pre_order = pre_order
        if pre_order_date is not None:
          self.pre_order_date = pre_order_date
        if reordered is not None:
          self.reordered = reordered
        if ship_to is not None:
          self.ship_to = ship_to
        if line_items is not None:
          self.line_items = line_items
        if bill_to is not None:
          self.bill_to = bill_to
        if total_offers_count is not None:
          self.total_offers_count = total_offers_count

    @property
    def amount_details(self):
        """
        Gets the amount_details of this Riskv1authenticationsOrderInformation.

        :return: The amount_details of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1authenticationsOrderInformationAmountDetails
        """
        return self._amount_details

    @amount_details.setter
    def amount_details(self, amount_details):
        """
        Sets the amount_details of this Riskv1authenticationsOrderInformation.

        :param amount_details: The amount_details of this Riskv1authenticationsOrderInformation.
        :type: Riskv1authenticationsOrderInformationAmountDetails
        """

        self._amount_details = amount_details

    @property
    def pre_order(self):
        """
        Gets the pre_order of this Riskv1authenticationsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :return: The pre_order of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._pre_order

    @pre_order.setter
    def pre_order(self, pre_order):
        """
        Sets the pre_order of this Riskv1authenticationsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :param pre_order: The pre_order of this Riskv1authenticationsOrderInformation.
        :type: str
        """

        self._pre_order = pre_order

    @property
    def pre_order_date(self):
        """
        Gets the pre_order_date of this Riskv1authenticationsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :return: The pre_order_date of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._pre_order_date

    @pre_order_date.setter
    def pre_order_date(self, pre_order_date):
        """
        Sets the pre_order_date of this Riskv1authenticationsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :param pre_order_date: The pre_order_date of this Riskv1authenticationsOrderInformation.
        :type: str
        """
        if pre_order_date is not None and len(pre_order_date) > 10:
            raise ValueError("Invalid value for `pre_order_date`, length must be less than or equal to `10`")

        self._pre_order_date = pre_order_date

    @property
    def reordered(self):
        """
        Gets the reordered of this Riskv1authenticationsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :return: The reordered of this Riskv1authenticationsOrderInformation.
        :rtype: bool
        """
        return self._reordered

    @reordered.setter
    def reordered(self, reordered):
        """
        Sets the reordered of this Riskv1authenticationsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :param reordered: The reordered of this Riskv1authenticationsOrderInformation.
        :type: bool
        """

        self._reordered = reordered

    @property
    def ship_to(self):
        """
        Gets the ship_to of this Riskv1authenticationsOrderInformation.

        :return: The ship_to of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1decisionsOrderInformationShipTo
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """
        Sets the ship_to of this Riskv1authenticationsOrderInformation.

        :param ship_to: The ship_to of this Riskv1authenticationsOrderInformation.
        :type: Riskv1decisionsOrderInformationShipTo
        """

        self._ship_to = ship_to

    @property
    def line_items(self):
        """
        Gets the line_items of this Riskv1authenticationsOrderInformation.
        This array contains detailed information about individual products in the order.

        :return: The line_items of this Riskv1authenticationsOrderInformation.
        :rtype: list[Riskv1authenticationsOrderInformationLineItems]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """
        Sets the line_items of this Riskv1authenticationsOrderInformation.
        This array contains detailed information about individual products in the order.

        :param line_items: The line_items of this Riskv1authenticationsOrderInformation.
        :type: list[Riskv1authenticationsOrderInformationLineItems]
        """

        self._line_items = line_items

    @property
    def bill_to(self):
        """
        Gets the bill_to of this Riskv1authenticationsOrderInformation.

        :return: The bill_to of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1authenticationsOrderInformationBillTo
        """
        return self._bill_to

    @bill_to.setter
    def bill_to(self, bill_to):
        """
        Sets the bill_to of this Riskv1authenticationsOrderInformation.

        :param bill_to: The bill_to of this Riskv1authenticationsOrderInformation.
        :type: Riskv1authenticationsOrderInformationBillTo
        """

        self._bill_to = bill_to

    @property
    def total_offers_count(self):
        """
        Gets the total_offers_count of this Riskv1authenticationsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :return: The total_offers_count of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._total_offers_count

    @total_offers_count.setter
    def total_offers_count(self, total_offers_count):
        """
        Sets the total_offers_count of this Riskv1authenticationsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :param total_offers_count: The total_offers_count of this Riskv1authenticationsOrderInformation.
        :type: str
        """
        if total_offers_count is not None and len(total_offers_count) > 2:
            raise ValueError("Invalid value for `total_offers_count`, length must be less than or equal to `2`")

        self._total_offers_count = total_offers_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationsOrderInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'settlement_method': 'str',
        'fraud_screening_level': 'str'
    }

    attribute_map = {
        'settlement_method': 'settlementMethod',
        'fraud_screening_level': 'fraudScreeningLevel'
    }

    def __init__(self, settlement_method=None, fraud_screening_level=None):
        """
        PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions - a model defined in Swagger
        """

        self._settlement_method = None
        self._fraud_screening_level = None

        if settlement_method is not None:
          self.settlement_method = settlement_method
        if fraud_screening_level is not None:
          self.fraud_screening_level = fraud_screening_level

    @property
    def settlement_method(self):
        """
        Gets the settlement_method of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        Method used for settlement.  Possible values: - `A`: Automated Clearing House (default for credits and for transactions using Canadian dollars) - `F`: Facsimile draft (U.S. dollars only) - `B`: Best possible (U.S. dollars only) (default if the field has not already been configured for your merchant ID)  For details, see `ecp_settlement_method` field description for credit cars and `ecp_debit_settlement_method` for debit cards in the [Electronic Check Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/EChecks_SCMP_API/html/) 

        :return: The settlement_method of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        :rtype: str
        """
        return self._settlement_method

    @settlement_method.setter
    def settlement_method(self, settlement_method):
        """
        Sets the settlement_method of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        Method used for settlement.  Possible values: - `A`: Automated Clearing House (default for credits and for transactions using Canadian dollars) - `F`: Facsimile draft (U.S. dollars only) - `B`: Best possible (U.S. dollars only) (default if the field has not already been configured for your merchant ID)  For details, see `ecp_settlement_method` field description for credit cars and `ecp_debit_settlement_method` for debit cards in the [Electronic Check Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/EChecks_SCMP_API/html/) 

        :param settlement_method: The settlement_method of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        :type: str
        """
        if settlement_method is not None and len(settlement_method) > 1:
            raise ValueError("Invalid value for `settlement_method`, length must be less than or equal to `1`")

        self._settlement_method = settlement_method

    @property
    def fraud_screening_level(self):
        """
        Gets the fraud_screening_level of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        Level of fraud screening.  Possible values: - `1`: Validation — default if the field has not already been configured for your merchant ID - `2`: Verification  For a description of this feature and a list of supported processors, see \"Verification and Validation\" in the [Electronic Check Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/EChecks_SCMP_API/html/). 

        :return: The fraud_screening_level of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        :rtype: str
        """
        return self._fraud_screening_level

    @fraud_screening_level.setter
    def fraud_screening_level(self, fraud_screening_level):
        """
        Sets the fraud_screening_level of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        Level of fraud screening.  Possible values: - `1`: Validation — default if the field has not already been configured for your merchant ID - `2`: Verification  For a description of this feature and a list of supported processors, see \"Verification and Validation\" in the [Electronic Check Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/EChecks_SCMP_API/html/). 

        :param fraud_screening_level: The fraud_screening_level of this PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions.
        :type: str
        """
        if fraud_screening_level is not None and len(fraud_screening_level) > 1:
            raise ValueError("Invalid value for `fraud_screening_level`, length must be less than or equal to `1`")

        self._fraud_screening_level = fraud_screening_level

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseProcessingInformationBankTransferOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseOrderInformationShippingDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'gift_wrap': 'bool',
        'shipping_method': 'str'
    }

    attribute_map = {
        'gift_wrap': 'giftWrap',
        'shipping_method': 'shippingMethod'
    }

    def __init__(self, gift_wrap=None, shipping_method=None):
        """
        TssV2TransactionsGet200ResponseOrderInformationShippingDetails - a model defined in Swagger
        """

        self._gift_wrap = None
        self._shipping_method = None

        if gift_wrap is not None:
          self.gift_wrap = gift_wrap
        if shipping_method is not None:
          self.shipping_method = shipping_method

    @property
    def gift_wrap(self):
        """
        Gets the gift_wrap of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        Boolean that indicates whether the customer requested gift wrapping for this purchase. This field can contain one of the following values: - true: The customer requested gift wrapping. - false: The customer did not request gift wrapping. 

        :return: The gift_wrap of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        :rtype: bool
        """
        return self._gift_wrap

    @gift_wrap.setter
    def gift_wrap(self, gift_wrap):
        """
        Sets the gift_wrap of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        Boolean that indicates whether the customer requested gift wrapping for this purchase. This field can contain one of the following values: - true: The customer requested gift wrapping. - false: The customer did not request gift wrapping. 

        :param gift_wrap: The gift_wrap of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        :type: bool
        """

        self._gift_wrap = gift_wrap

    @property
    def shipping_method(self):
        """
        Gets the shipping_method of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        Shipping method for the product. Possible values:   - `lowcost`: Lowest-cost service  - `sameday`: Courier or same-day service  - `oneday`: Next-day or overnight service  - `twoday`: Two-day service  - `threeday`: Three-day service  - `pickup`: Store pick-up  - `other`: Other shipping method  - `none`: No shipping method because product is a service or subscription 

        :return: The shipping_method of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        :rtype: str
        """
        return self._shipping_method

    @shipping_method.setter
    def shipping_method(self, shipping_method):
        """
        Sets the shipping_method of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        Shipping method for the product. Possible values:   - `lowcost`: Lowest-cost service  - `sameday`: Courier or same-day service  - `oneday`: Next-day or overnight service  - `twoday`: Two-day service  - `threeday`: Three-day service  - `pickup`: Store pick-up  - `other`: Other shipping method  - `none`: No shipping method because product is a service or subscription 

        :param shipping_method: The shipping_method of this TssV2TransactionsGet200ResponseOrderInformationShippingDetails.
        :type: str
        """
        if shipping_method is not None and len(shipping_method) > 10:
            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `10`")

        self._shipping_method = shipping_method

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseOrderInformationShippingDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsMerchantInformationMerchantDescriptor(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'alternate_name': 'str',
        'contact': 'str',
        'address1': 'str',
        'locality': 'str',
        'country': 'str',
        'postal_code': 'str',
        'administrative_area': 'str',
        'phone': 'str',
        'url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'alternate_name': 'alternateName',
        'contact': 'contact',
        'address1': 'address1',
        'locality': 'locality',
        'country': 'country',
        'postal_code': 'postalCode',
        'administrative_area': 'administrativeArea',
        'phone': 'phone',
        'url': 'url'
    }

    def __init__(self, name=None, alternate_name=None, contact=None, address1=None, locality=None, country=None, postal_code=None, administrative_area=None, phone=None, url=None):
        """
        Ptsv2paymentsMerchantInformationMerchantDescriptor - a model defined in Swagger
        """

        self._name = None
        self._alternate_name = None
        self._contact = None
        self._address1 = None
        self._locality = None
        self._country = None
        self._postal_code = None
        self._administrative_area = None
        self._phone = None
        self._url = None

        if name is not None:
          self.name = name
        if alternate_name is not None:
          self.alternate_name = alternate_name
        if contact is not None:
          self.contact = contact
        if address1 is not None:
          self.address1 = address1
        if locality is not None:
          self.locality = locality
        if country is not None:
          self.country = country
        if postal_code is not None:
          self.postal_code = postal_code
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if phone is not None:
          self.phone = phone
        if url is not None:
          self.url = url

    @property
    def name(self):
        """
        Gets the name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Your merchant name.  **Note** For Paymentech processor using Cybersource Payouts, the maximum data length is 22.  #### PIN debit Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests.  #### Airline processing Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  **Note** Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field.  **Important** This value must consist of English characters.  Required for captures and credits. 

        :return: The name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Your merchant name.  **Note** For Paymentech processor using Cybersource Payouts, the maximum data length is 22.  #### PIN debit Your business name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests.  #### Airline processing Your merchant name. This name is displayed on the cardholder’s statement. When you include more than one consecutive space, extra spaces are removed.  **Note** Some airline fee programs may require the original ticket number (ticket identifier) or the ancillary service description in positions 13 through 23 of this field.  **Important** This value must consist of English characters.  Required for captures and credits. 

        :param name: The name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._name = name

    @property
    def alternate_name(self):
        """
        Gets the alternate_name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        An alternate name for the merchant.  For the descriptions, used-by information, data types, and lengths for these fields, see the `merchant_descriptor_alternate` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> 

        :return: The alternate_name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._alternate_name

    @alternate_name.setter
    def alternate_name(self, alternate_name):
        """
        Sets the alternate_name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        An alternate name for the merchant.  For the descriptions, used-by information, data types, and lengths for these fields, see the `merchant_descriptor_alternate` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> 

        :param alternate_name: The alternate_name of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if alternate_name is not None and len(alternate_name) > 13:
            raise ValueError("Invalid value for `alternate_name`, length must be less than or equal to `13`")

        self._alternate_name = alternate_name

    @property
    def contact(self):
        """
        Gets the contact of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_contact` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> Contact information for the merchant.  **Note** These are the maximum data lengths for the following payment processors: - FDCCompass (13) - Paymentech (13) 

        :return: The contact of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """
        Sets the contact of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_contact` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)--> Contact information for the merchant.  **Note** These are the maximum data lengths for the following payment processors: - FDCCompass (13) - Paymentech (13) 

        :param contact: The contact of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if contact is not None and len(contact) > 14:
            raise ValueError("Invalid value for `contact`, length must be less than or equal to `14`")

        self._contact = contact

    @property
    def address1(self):
        """
        Gets the address1 of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        First line of merchant's address. For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_street` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The address1 of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        First line of merchant's address. For the descriptions, used-by information, data types, and lengths for these fields, see `merchant_descriptor_street` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param address1: The address1 of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if address1 is not None and len(address1) > 60:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `60`")

        self._address1 = address1

    @property
    def locality(self):
        """
        Gets the locality of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's City.  #### PIN debit City for your business location. This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests. 

        :return: The locality of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's City.  #### PIN debit City for your business location. This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  Optional field for PIN debit credit or PIN debit purchase requests. 

        :param locality: The locality of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if locality is not None and len(locality) > 13:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `13`")

        self._locality = locality

    @property
    def country(self):
        """
        Gets the country of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's country.  #### PIN debit Country code for your business location. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters. **Note** If your business is located in the U.S. or Canada and you include this field in a request, you must also include `merchantInformation.merchantDescriptor.administrativeArea`.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The country of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's country.  #### PIN debit Country code for your business location. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters. **Note** If your business is located in the U.S. or Canada and you include this field in a request, you must also include `merchantInformation.merchantDescriptor.administrativeArea`.  Optional field for PIN debit credit or PIN debit purchase. 

        :param country: The country of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._country = country

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's postal code.  #### PIN debit Postal code for your business location. This value might be displayed on the cardholder’s statement.  If your business is domiciled in the U.S., you can use a 5-digit or 9-digit postal code. A 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example: `12345-6789`  If your business is domiciled in Canada, you can use a 6-digit or 9-digit postal code. A 6-digit postal code must follow this format: [alpha][numeric][alpha][space] [numeric][alpha][numeric] Example: `A1B 2C3`  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada. **Important** Mastercard requires a postal code for any country that uses postal codes. You can provide the postal code in your account or you can include this field in your request.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The postal_code of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchant's postal code.  #### PIN debit Postal code for your business location. This value might be displayed on the cardholder’s statement.  If your business is domiciled in the U.S., you can use a 5-digit or 9-digit postal code. A 9-digit postal code must follow this format: [5 digits][dash][4 digits] Example: `12345-6789`  If your business is domiciled in Canada, you can use a 6-digit or 9-digit postal code. A 6-digit postal code must follow this format: [alpha][numeric][alpha][space] [numeric][alpha][numeric] Example: `A1B 2C3`  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada. **Important** Mastercard requires a postal code for any country that uses postal codes. You can provide the postal code in your account or you can include this field in your request.  Optional field for PIN debit credit or PIN debit purchase. 

        :param postal_code: The postal_code of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 14:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `14`")

        self._postal_code = postal_code

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        The state where the merchant is located.  #### PIN debit State code or region code for your business. Use the Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada.  Optional field for PIN debit credit or PIN debit purchase. 

        :return: The administrative_area of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        The state where the merchant is located.  #### PIN debit State code or region code for your business. Use the Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf) This value might be displayed on the cardholder’s statement.  When you do not include this value in your PIN debit request, the merchant name from your account is used. **Important** This value must consist of English characters.  **Note** This field is supported only for businesses located in the U.S. or Canada.  Optional field for PIN debit credit or PIN debit purchase. 

        :param administrative_area: The administrative_area of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """

        self._administrative_area = administrative_area

    @property
    def phone(self):
        """
        Gets the phone of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchnat phone as contact information for CNP transactions 

        :return: The phone of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Merchnat phone as contact information for CNP transactions 

        :param phone: The phone of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if phone is not None and len(phone) > 13:
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `13`")

        self._phone = phone

    @property
    def url(self):
        """
        Gets the url of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Address of company's website provided by merchant 

        :return: The url of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        Address of company's website provided by merchant 

        :param url: The url of this Ptsv2paymentsMerchantInformationMerchantDescriptor.
        :type: str
        """
        if url is not None and len(url) > 255:
            raise ValueError("Invalid value for `url`, length must be less than or equal to `255`")

        self._url = url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsMerchantInformationMerchantDescriptor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationsetupsProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_solution': 'str',
        'visa_checkout_id': 'str'
    }

    attribute_map = {
        'payment_solution': 'paymentSolution',
        'visa_checkout_id': 'visaCheckoutId'
    }

    def __init__(self, payment_solution=None, visa_checkout_id=None):
        """
        Riskv1authenticationsetupsProcessingInformation - a model defined in Swagger
        """

        self._payment_solution = None
        self._visa_checkout_id = None

        if payment_solution is not None:
          self.payment_solution = payment_solution
        if visa_checkout_id is not None:
          self.visa_checkout_id = visa_checkout_id

    @property
    def payment_solution(self):
        """
        Gets the payment_solution of this Riskv1authenticationsetupsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :return: The payment_solution of this Riskv1authenticationsetupsProcessingInformation.
        :rtype: str
        """
        return self._payment_solution

    @payment_solution.setter
    def payment_solution(self, payment_solution):
        """
        Sets the payment_solution of this Riskv1authenticationsetupsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :param payment_solution: The payment_solution of this Riskv1authenticationsetupsProcessingInformation.
        :type: str
        """
        if payment_solution is not None and len(payment_solution) > 12:
            raise ValueError("Invalid value for `payment_solution`, length must be less than or equal to `12`")

        self._payment_solution = payment_solution

    @property
    def visa_checkout_id(self):
        """
        Gets the visa_checkout_id of this Riskv1authenticationsetupsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :return: The visa_checkout_id of this Riskv1authenticationsetupsProcessingInformation.
        :rtype: str
        """
        return self._visa_checkout_id

    @visa_checkout_id.setter
    def visa_checkout_id(self, visa_checkout_id):
        """
        Sets the visa_checkout_id of this Riskv1authenticationsetupsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :param visa_checkout_id: The visa_checkout_id of this Riskv1authenticationsetupsProcessingInformation.
        :type: str
        """
        if visa_checkout_id is not None and len(visa_checkout_id) > 48:
            raise ValueError("Invalid value for `visa_checkout_id`, length must be less than or equal to `48`")

        self._visa_checkout_id = visa_checkout_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationsetupsProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class CustomerApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def delete_customer(self, customer_token_id, **kwargs):
        """
        Delete a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_customer(customer_token_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_customer_with_http_info(customer_token_id, **kwargs)
        else:
            (data) = self.delete_customer_with_http_info(customer_token_id, **kwargs)
            return data

    def delete_customer_with_http_info(self, customer_token_id, **kwargs):
        """
        Delete a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_customer_with_http_info(customer_token_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_token_id', 'profile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_token_id' is set
        if ('customer_token_id' not in params) or (params['customer_token_id'] is None):
            raise ValueError("Missing the required parameter `customer_token_id` when calling `delete_customer`")

        if 'customer_token_id' in params and len(params['customer_token_id']) > 32:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `delete_customer`, length must be less than or equal to `32`")
        if 'customer_token_id' in params and len(params['customer_token_id']) < 1:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `delete_customer`, length must be greater than or equal to `1`")
        if 'profile_id' in params and len(params['profile_id']) > 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `delete_customer`, length must be less than or equal to `36`")
        if 'profile_id' in params and len(params['profile_id']) < 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `delete_customer`, length must be greater than or equal to `36`")

        collection_formats = {}

        path_params = {}
        if 'customer_token_id' in params:
            path_params['customerTokenId'] = params['customer_token_id']

        query_params = []

        header_params = {}
        if 'profile_id' in params:
            header_params['profile-id'] = params['profile_id']

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/tms/v2/customers/{customer_token_id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_customer(self, customer_token_id, **kwargs):
        """
        Retrieve a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_customer(customer_token_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_customer_with_http_info(customer_token_id, **kwargs)
        else:
            (data) = self.get_customer_with_http_info(customer_token_id, **kwargs)
            return data

    def get_customer_with_http_info(self, customer_token_id, **kwargs):
        """
        Retrieve a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_customer_with_http_info(customer_token_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_token_id', 'profile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_token_id' is set
        if ('customer_token_id' not in params) or (params['customer_token_id'] is None):
            raise ValueError("Missing the required parameter `customer_token_id` when calling `get_customer`")

        if 'customer_token_id' in params and len(params['customer_token_id']) > 32:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `get_customer`, length must be less than or equal to `32`")
        if 'customer_token_id' in params and len(params['customer_token_id']) < 1:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `get_customer`, length must be greater than or equal to `1`")
        if 'profile_id' in params and len(params['profile_id']) > 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `get_customer`, length must be less than or equal to `36`")
        if 'profile_id' in params and len(params['profile_id']) < 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `get_customer`, length must be greater than or equal to `36`")

        collection_formats = {}

        path_params = {}
        if 'customer_token_id' in params:
            path_params['customerTokenId'] = params['customer_token_id']

        query_params = []

        header_params = {}
        if 'profile_id' in params:
            header_params['profile-id'] = params['profile_id']

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/tms/v2/customers/{customer_token_id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='TmsV2CustomersResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def patch_customer(self, customer_token_id, patch_customer_request, **kwargs):
        """
        Update a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_customer(customer_token_id, patch_customer_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param PatchCustomerRequest patch_customer_request: (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :param str if_match: Contains an ETag value from a GET request to make the request conditional.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.patch_customer_with_http_info(customer_token_id, patch_customer_request, **kwargs)
        else:
            (data) = self.patch_customer_with_http_info(customer_token_id, patch_customer_request, **kwargs)
            return data

    def patch_customer_with_http_info(self, customer_token_id, patch_customer_request, **kwargs):
        """
        Update a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_customer_with_http_info(customer_token_id, patch_customer_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str customer_token_id: The TokenId of a customer. (required)
        :param PatchCustomerRequest patch_customer_request: (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :param str if_match: Contains an ETag value from a GET request to make the request conditional.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_token_id', 'patch_customer_request', 'profile_id', 'if_match']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_token_id' is set
        if ('customer_token_id' not in params) or (params['customer_token_id'] is None):
            raise ValueError("Missing the required parameter `customer_token_id` when calling `patch_customer`")
        # verify the required parameter 'patch_customer_request' is set
        if ('patch_customer_request' not in params) or (params['patch_customer_request'] is None):
            raise ValueError("Missing the required parameter `patch_customer_request` when calling `patch_customer`")

        if 'customer_token_id' in params and len(params['customer_token_id']) > 32:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `patch_customer`, length must be less than or equal to `32`")
        if 'customer_token_id' in params and len(params['customer_token_id']) < 1:
            raise ValueError("Invalid value for parameter `customer_token_id` when calling `patch_customer`, length must be greater than or equal to `1`")
        if 'profile_id' in params and len(params['profile_id']) > 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `patch_customer`, length must be less than or equal to `36`")
        if 'profile_id' in params and len(params['profile_id']) < 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `patch_customer`, length must be greater than or equal to `36`")
        if 'if_match' in params and len(params['if_match']) > 32:
            raise ValueError("Invalid value for parameter `if_match` when calling `patch_customer`, length must be less than or equal to `32`")
        if 'if_match' in params and len(params['if_match']) < 1:
            raise ValueError("Invalid value for parameter `if_match` when calling `patch_customer`, length must be greater than or equal to `1`")

        collection_formats = {}

        path_params = {}
        if 'customer_token_id' in params:
            path_params['customerTokenId'] = params['customer_token_id']

        query_params = []

        header_params = {}
        if 'profile_id' in params:
            header_params['profile-id'] = params['profile_id']
        if 'if_match' in params:
            header_params['if-match'] = params['if_match']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patch_customer_request' in params:
            body_params = params['patch_customer_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/tms/v2/customers/{customer_token_id}', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='TmsV2CustomersResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_customer(self, post_customer_request, **kwargs):
        """
        Create a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_customer(post_customer_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PostCustomerRequest post_customer_request: (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.post_customer_with_http_info(post_customer_request, **kwargs)
        else:
            (data) = self.post_customer_with_http_info(post_customer_request, **kwargs)
            return data

    def post_customer_with_http_info(self, post_customer_request, **kwargs):
        """
        Create a Customer
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_customer_with_http_info(post_customer_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param PostCustomerRequest post_customer_request: (required)
        :param str profile_id: The id of a profile containing user specific TMS configuration.
        :return: TmsV2CustomersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['post_customer_request', 'profile_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_customer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'post_customer_request' is set
        if ('post_customer_request' not in params) or (params['post_customer_request'] is None):
            raise ValueError("Missing the required parameter `post_customer_request` when calling `post_customer`")

        if 'profile_id' in params and len(params['profile_id']) > 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `post_customer`, length must be less than or equal to `36`")
        if 'profile_id' in params and len(params['profile_id']) < 36:
            raise ValueError("Invalid value for parameter `profile_id` when calling `post_customer`, length must be greater than or equal to `36`")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'profile_id' in params:
            header_params['profile-id'] = params['profile_id']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'post_customer_request' in params:
            body_params = params['post_customer_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/tms/v2/customers', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='TmsV2CustomersResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
